pub fn sys_vfs_change_directory(trapframe: &mut Trapframe) -> usizeExpand description
Change current working directory using VFS (VfsChangeDirectory)
This system call changes the current working directory of the calling task to the specified path using the VFS layer.
Arguments
trapframe.get_arg(0)- Pointer to the null-terminated path string
Returns
0on successusize::MAXon error (path not found, not a directory, etc.)